@@ -41,7 +41,6 @@ import numpy as np
 from mu32.core import Mu32, mu32log, logging
 
 
-
 mu32log.setLevel( logging.INFO )
 
 def main():
@@ -62,33 +61,26 @@ def main():
 
 
 def my_autotest_function( mu32: Mu32 ):
-	"""
-	The data processing function is called  after the acquisition process has finished.
-	In the following we compute energy on all mems. Inactive MEMs have zero energy
-	"""
-
-	q_size = mu32.signal_q.qsize()
-	if q_size== 0:
-		raise Exception( 'No received data !' )
 
 	"""
 	get queued signals from Mu32
 	"""
-	signal = []
-	for _ in range( q_size ):
-		signal = np.append( signal, mu32.signal_q.get( block=False ) )
-	signal = signal.reshape( mu32.buffer_length * q_size, mu32.mems_number )
+	q_size = mu32.signal_q.qsize()
+	signal = mu32.signal_q.get()
+	while not mu32.signal_q.empty():
+		signal = np.append( signal, mu32.signal_q.get(), axis=1 )
 
 	"""
 	compute mean energy
 	"""
-	mic_power = np.sum( signal**2, axis=0 )
+	mic_power = np.sum( signal**2, axis=1 )
+	n_samples = np.size( signal, 1 )
 		
 	print( 'Autotest results:')
 	print( '-'*20 )
-	print( ' .counted', q_size, 'recorded data buffers' )
-	print( ' .equivalent recording time is:', q_size * mu32.buffer_length / mu32.sampling_frequency, 's' )
-	print( ' .detected', len( np.where( mic_power > 0 )[0] ), 'active MEMs:', np.where( mic_power > 0 )[0] )
+	print( f" .counted {q_size} recorded data buffers" )
+	print( f" .equivalent recording time is: {n_samples / mu32.sampling_frequency} " )
+	print( f" .detected {len( np.where( mic_power > 0 )[0] )} active MEMs: {np.where( mic_power > 0 )[0]}" )
 	print( '-'*20 )
 
 if __name__ == "__main__":
