@@ -63,6 +63,7 @@ MEMS = (0, 7)					# the two Mu32 antenna microphones used
 MEMS_NUMBER = len( MEMS )
 DURATION = 0					# Time recording in seconds. 0 means infinite acquisition loop: use Ctrl C for stopping
 
+
 def main():
 	"""
 	run the Mu32 system during one second for getting and ploting signals comming from
@@ -89,8 +90,9 @@ def main():
 			callback=callback_play,
 			finished_callback=event.set
 		)
-	except:
+	except Exception as e:
 		print( 'Unexpected error:', sys.exc_info()[0] )
+		print( e )
 		exit()
 
 	print('Starting Playback ...')
@@ -124,14 +126,14 @@ def callback_read( mu32: Mu32, data: np.ndarray ):
 	"""
 	global signal_q
 	data >>= 7
-	signal_q.put( data.astype( np.int16 ).reshape( mu32.buffer_length, mu32.mems_number ) )
+	signal_q.put( data.astype( np.int16 ) )
 
 def callback_play( outdata, frames, time, status ):
 	"""
 	callback function for playing signal:
 	get the signal from queue and send it to the audio device
 	"""
-	outdata[:] = signal_q.get()
+	outdata[:] = signal_q.get().T
 
 def callback_play_safe( outdata, frames, time, status ):
 	"""
@@ -142,7 +144,7 @@ def callback_play_safe( outdata, frames, time, status ):
 		raise sd.CallbackAbort
 
 	try:
-		data = signal_q.get()
+		data = signal_q.get().T
 	except queue.Empty as e:
 		print(' Buffer is empty: increase buffersize?' )
 		raise sd.CallbackAbort from e
