@@ -50,9 +50,8 @@ MEMS_NUMBER = len( MEMS )
 DURATION = 1
 
 plt.ion()                                       # Turn the interactive mode on.
-fig, axs = plt.subplots( MEMS_NUMBER )          # init figure with MEMS_NUMBVER subplots
+fig, axs = plt.subplots( MEMS_NUMBER )# init figure with MEMS_NUMBER subplots + one is COUNTER True
 fig.suptitle('Mems signals')
-t0 = 0                                          # time index used for signals plotting
 
 def main():
 
@@ -70,21 +69,18 @@ def main():
 	except:
 		print( 'aborting' )
 
-def my_callback_fn( mu32: Mu32, data ):
-    """
-    Plot signals comming from the Mu32 receiver
-    """
-    global t0
-    signal = data.reshape( mu32.buffer_length, mu32.mems_number )
 
-    time = np.array( [t for t in range( mu32.buffer_length )] ) / mu32.sampling_frequency + ( t0 * mu32.buffer_length / mu32.sampling_frequency )
-    for s in range( MEMS_NUMBER ):
-        X = signal[:,s]
-        axs[s].plot( time, X )
+def my_callback_fn( mu32: Mu32, data, counter=None ):
+	"""
+	Plot signals comming from the Mu32 receiver
+	"""
 
-    plt.show()
-    plt.pause( 10**-10 )
-    t0 += 1
+	time = np.array( [t for t in range( mu32.buffer_length )] ) / mu32.sampling_frequency
+	for s in range( mu32.mems_number ):
+		axs[s].cla()
+		axs[s].plot( time, data[s,:] )
+		
+	plt.pause( 0.000001 )
 
 
 if __name__ == "__main__":
