@@ -43,6 +43,9 @@ import numpy as np
 import matplotlib.pyplot as plt
 from mu32.core import Mu32, logging, mu32log
 
+MEMS = (0, 1, 2, 3, 4, 5, 6, 7)
+DURATION = 1
+
 mu32log.setLevel( logging.INFO )
 
 def main():
@@ -55,48 +58,49 @@ def main():
 		mu32 = Mu32()
 		mu32.run( 
 			post_callback_fn=my_callback_end_function, 	# the user defined data processing function
-			mems=(0, 1, 2, 3, 4, 5, 6, 7)				# activated mems			
+			mems=MEMS,				# activated mems
+			duration=DURATION,
 		)
-	except:
-		print( 'aborting' )
+	except Exception as e:
+		print( 'aborting: ', e )
 
 
 def my_callback_end_function( mu32: Mu32 ):
-	"""
-	The data processing function is called  after the acquisition process has finished.
-	It plots signals from microphones that have been activated in the Mu32.run() function 
-	"""
-
-	q_size = mu32.signal_q.qsize()
-	if q_size== 0:
-		raise Exception( 'No received data !' )
-
-	print( 'got %d transfer buffers from %d microphones' % (q_size, mu32.mems_number) )	
-
+	
 	"""
 	get queued signals from Mu32
 	"""
-	signal = []
-	for _ in range( q_size ):
-		signal = np.append( signal, mu32.signal_q.get( block=False ) )
-
-	signal = signal.reshape( mu32.buffer_length * q_size, mu32.mems_number )
+	signal = mu32.signal_q.get()
+	while not mu32.signal_q.empty():
+		signal = np.append( signal, mu32.signal_q.get(), axis=1 )
 
 	"""
-	plot mems signals 
+	plot mems signals
 	"""
-	fig, axs = plt.subplots( mu32.mems_number )
-	fig.suptitle('Mems activity')
-	time = np.array( [t for t in range( mu32.buffer_length * q_size )] )/mu32.sampling_frequency
-	for s in range( mu32.mems_number ):
-		X = signal[:,s]
-		X_std = ( (X - X.min(axis=0)) / (X.max(axis=0) - X.min(axis=0) ) * 2 ) - 1
-		axs[s].plot( time, X_std )
-		axs[s].set( xlabel='time in seconds', ylabel='mic %d' % s )
+	time = np.array( range( np.size(signal,1) ) )/mu32.sampling_frequency
+	if mu32.mems_number > 1:
+		"""
+		draw multiplot
+		"""
+		fig, axs = plt.subplots( mu32.mems_number )
+		fig.suptitle('Mems activity')
+	
+		for s in range( mu32.mems_number ):
+			X = signal[s,:] * mu32.sensibility
+			axs[s].plot( time, X )
+			axs[s].set( xlabel='time in seconds', ylabel='mic %d' % s )
+	else:
+		"""
+		draw simple plot
+		"""
+		plt.plot( time, signal[0,:] )
+		plt.xlabel( 'time in seconds' )
+		plt.ylabel( f"microphone {mu32.mems[0]}" )
 
 	plt.show()
 
 
 
+
 if __name__ == "__main__":
 	main()
\ No newline at end of file
