@@ -46,6 +46,10 @@ import sounddevice as sd
 import matplotlib.pyplot as plt
 from mu32.core import Mu32, logging, mu32log
 
+MEMS = (0, 7)
+DURATION = 1
+WAV_FILENAME = 'test.wav'
+
 mu32log.setLevel( logging.INFO )
 
 def main():
@@ -58,41 +62,26 @@ def main():
         mu32 = Mu32()
         mu32.run(
 		    post_callback_fn=my_callback_end_function, 	# the user defined data processing function
-		    mems=(0, 7),                                # activated mems
-            duration=1                                  # recording time
+		    mems=MEMS,                                # activated mems
+            duration=DURATION                         # recording time
         )
     except Exception as e:
         print( str( e ) )
 
 
 def my_callback_end_function( mu32: Mu32 ):
-    """
-    The data processing function is called  after the acquisition process has finished.
-    It records signals from the two microphones that have been activated in the Mu32.run() function 
-    """
-
-    q_size = mu32.signal_q.qsize()
-    if q_size== 0:
-        raise Exception( 'No received data !' )
-
-    print( 'got %d transfer buffers from %d microphones (recording time is: %f s)' % (q_size, mu32.mems_number, q_size*mu32.buffer_length/mu32.sampling_frequency) )	
-
-    """
-    Open wavfile and write header
-    """
-    wav_filename = 'test.wav'
-    wavfile = wave.open( wav_filename, mode='wb' )
-    wavfile.setnchannels(2)
-    wavfile.setsampwidth(2)
-    wavfile.setframerate( mu32.sampling_frequency )
-
     """
     get queued signals from Mu32 and save them in wavfile
     """
-    sig = []
-    for _ in range( mu32.signal_q.qsize() ):
-        wavfile.writeframesraw( np.int16( mu32.signal_q.get( block=False ) ) )
-
-    wavfile.close()
+    
+    with  wave.open( WAV_FILENAME, mode='wb' ) as wavfile:
+        wavfile.setnchannels(2)
+        wavfile.setsampwidth(2)
+        wavfile.setframerate( mu32.sampling_frequency )
 
+        while not mu32.signal_q.empty():
+            signal = mu32.signal_q.get() >> 4
+            wavfile.writeframesraw( np.int16( np.reshape( signal, np.size( signal ), order='F' ) ) )    
 
+if __name__ == "__main__":
+	main()
\ No newline at end of file
